@@ -21,18 +21,23 @@ class spartaquant():
     def authenticate(self):
         # **************************************************************************************************************
         bInternalJupyterDesktop = False
-        try:
-            self.URL_BASE, self.USER_ID = self.getDBAuthFunc()
-            bInternalJupyterDesktop = True
-        except Exception as e:
-            pass
+        # try:
+        #     self.URL_BASE, self.USER_ID = self.getDBAuthFunc()
+        #     bInternalJupyterDesktop = True
+        # except Exception as e:
+        #     pass
         
         def printError():
             print("Authentication failed. Make sure you have entered the correct accessKey")
 
         if not bInternalJupyterDesktop:
             accessKey = getpass.getpass(prompt="Enter your access key")
-            mainUrl = self.decodeMainUrl(accessKey)
+            try:
+                mainUrl = self.decodeMainUrl(accessKey)
+            except:
+                printError()
+                return
+                
             validateUrl = mainUrl+'validateMainUrlExternalApi'
             newJson = dict()
             json_data = dict()
@@ -48,6 +53,7 @@ class spartaquant():
                     if res == 1:
                         self.URL_BASE = mainUrl
                         self.USER_ID = self.decodeb64(self.decodeb64(resJson['userId']))
+                        print("You are logged "+str(chr(0x2713)))
                     else:
                         printError()
                 else:
@@ -175,6 +181,42 @@ class spartaquant():
         funcName = str(inspect.stack()[0][0].f_code.co_name)
         return self.sendRequests(funcName, functionName2Create, functionSource)
 
+    def putXlsData(self, xlsId, data_df, sheetName, cellStart='A1'):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, xlsId, data_df, sheetName, cellStart)
+
+    def createXls(self, nameFile, extension='xlsx'):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, nameFile, extension)
+
+    def getXlsDB(self):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName)
+
+    def getXlsData(self, xlsId, sheetName=None, formula=None, dispoDate=None):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, xlsId, sheetName, formula, dispoDate)
+
+    def getXlsDispoDates(self, xlsId):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, xlsId)
+
+    def getXlsData(self, xlsId, sheetName=None, formula=None, dispoDate=None):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, xlsId, sheetName, formula)
+
+    def getExternalDB(self):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName)
+
+    def getExternalData(self, authDBId, tableName=None, formula=None):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, authDBId, tableName, formula)
+
+    def putExternalData(self, authDBId, tableName, formula):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, authDBId, tableName, formula)
+
     def testFunction(self, functionObj, *args):
         print("test function")
         print("args")
